Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(327)

Unified Diff: include/core/SkRRect.h

Issue 41253002: Checking structure sizes before reading them from memory to avoid overflowing the buffer's stream. (Closed) Base URL: https://skia.googlecode.com/svn/trunk
Patch Set: Fixed comments and added tests Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: include/core/SkRRect.h
diff --git a/include/core/SkRRect.h b/include/core/SkRRect.h
index 32d62856bc90fddec1a33196f8f691ce8506de68..68bac5f501a94144e27037cfd684dcf573cf7ea8 100644
--- a/include/core/SkRRect.h
+++ b/include/core/SkRRect.h
@@ -268,14 +268,19 @@ public:
* write kSizeInMemory bytes, and that value is guaranteed to always be
* a multiple of 4. Return kSizeInMemory.
*/
- uint32_t writeToMemory(void* buffer) const;
+ size_t writeToMemory(void* buffer) const;
/**
* Read the rrect from the specified buffer. This is guaranteed to always
* read kSizeInMemory bytes, and that value is guaranteed to always be
* a multiple of 4. Return kSizeInMemory.
*/
- uint32_t readFromMemory(const void* buffer);
+ size_t readFromMemory(const void* buffer, size_t length);
private:
SkRect fRect;
« no previous file with comments | « include/core/SkPath.h ('k') | include/core/SkReader32.h » ('j') | include/core/SkReader32.h » ('J')
@@ -268,14 +268,19 @@ public:
/**
- * Read the rrect from the specified buffer. This is guaranteed to always
- * read kSizeInMemory bytes, and that value is guaranteed to always be
- * a multiple of 4. Return kSizeInMemory.
+ * Reads the rrect from the specified buffer
+ *
+ * If the specified buffer is large enough, this will read kSizeInMemory bytes,
+ * and that value is guaranteed to always be a multiple of 4.
+ *
+ * @param buffer Memory to read from
+ * @param length Amount of memory available in the buffer
+ * @return kSizeInMemory or 0 if there was not enough memory available
*/

Powered by Google App Engine
This is Rietveld 408576698